==> openshift-serverless-logic-1.29.0-src.zip: openshift-serverless-logic-1.29.0.GA-src/org.kie.kogito-kogito-runtimes-1.38.0.Final/quarkus/addons/knative/serving/runtime/src/main/java/org/kie/kogito/addons/quarkus/knative/serving/customfunctions/KnativeWorkItemHandler.java <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.addons.quarkus.knative.serving.customfunctions;

import java.util.Map;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;

import org.kie.kogito.internal.process.runtime.KogitoWorkItem;
import org.kie.kogito.serverless.workflow.WorkflowWorkItemHandler;

@ApplicationScoped
public final class KnativeWorkItemHandler extends WorkflowWorkItemHandler {

    public static final String NAME = "knative";

    public static final String OPERATION_PROPERTY_NAME = "operation";

    private final KnativeServerlessWorkflowCustomFunction customFunction;

    @Inject
    public KnativeWorkItemHandler(KnativeServerlessWorkflowCustomFunction customFunction) {
        this.customFunction = customFunction;
    }

    @Override
    protected Object internalExecute(KogitoWorkItem workItem, Map<String, Object> arguments) {
        return customFunction.execute(workItem.getProcessInstanceStringId(), workItem.getNodeInstance().getNode().getMetaData(), arguments);
    }

    @Override
    public String getName() {
        return NAME;
    }
}

==> openshift-serverless-logic-1.30.0-src.zip: openshift-serverless-logic-1.30.0.GA-src/org.kie.kogito-kogito-runtimes-1.40.0.Final/quarkus/addons/knative/serving/runtime/src/main/java/org/kie/kogito/addons/quarkus/knative/serving/customfunctions/KnativeWorkItemHandler.java <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.addons.quarkus.knative.serving.customfunctions;

import java.util.Map;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;

import org.kie.kogito.internal.process.runtime.KogitoWorkItem;
import org.kie.kogito.serverless.workflow.WorkflowWorkItemHandler;

@ApplicationScoped
public final class KnativeWorkItemHandler extends WorkflowWorkItemHandler {

    public static final String NAME = "knative";

    public static final String OPERATION_PROPERTY_NAME = "operation";

    private final KnativeServerlessWorkflowCustomFunction customFunction;

    @Inject
    public KnativeWorkItemHandler(KnativeServerlessWorkflowCustomFunction customFunction) {
        this.customFunction = customFunction;
    }

    @Override
    protected Object internalExecute(KogitoWorkItem workItem, Map<String, Object> arguments) {
        var operation = (String) workItem.getNodeInstance().getNode().getMetaData().get(OPERATION_PROPERTY_NAME);
        return customFunction.execute(workItem.getProcessInstanceStringId(), operation, arguments);
    }

    @Override
    public String getName() {
        return NAME;
    }
}
